@@ -5,12 +5,22 @@ use base qw(Exporter);
 
 our @EXPORT = qw(
   match_and match_or match_not match_method match_path match_path_strip
-  match_extension match_query match_body match_uploads
+  match_extension match_query match_body match_uploads match_true match_false
 );
 
+sub _matcher { bless shift, 'Web::Dispatch::Matcher' }
+
+sub match_true {
+  _matcher(sub { {} });
+}
+
+sub match_false {
+  _matcher(sub {});
+}
+
 sub match_and {
   my @match = @_;
-  sub {
+  _matcher(sub {
     my ($env) = @_;
     my $my_env = { 'Web::Dispatch.original_env' => $env, %$env };
     my $new_env;
@@ -26,54 +36,54 @@ sub match_and {
       }
     }
     return ($new_env, @got);
-  }
+  })
 }
 
 sub match_or {
   my @match = @_;
-  sub {
+  _matcher(sub {
     foreach my $try (@match) {
       if (my @ret = $try->(@_)) {
         return @ret;
       }
     }
     return;
-  }
+  })
 }
 
 sub match_not {
   my ($match) = @_;
-  sub {
+  _matcher(sub {
     if (my @discard = $match->($_[0])) {
       ();
     } else {
       ({});
     }
-  }
+  })
 }
 
 sub match_method {
   my ($method) = @_;
-  sub {
+  _matcher(sub {
     my ($env) = @_;
     $env->{REQUEST_METHOD} eq $method ? {} : ()
-  }
+  })
 }
 
 sub match_path {
   my ($re) = @_;
-  sub {
+  _matcher(sub {
     my ($env) = @_;
     if (my @cap = ($env->{PATH_INFO} =~ /$re/)) {
       $cap[0] = {}; return @cap;
     }
     return;
-  }
+  })
 }
 
 sub match_path_strip {
   my ($re) = @_;
-  sub {
+  _matcher(sub {
     my ($env) = @_;
     if (my @cap = ($env->{PATH_INFO} =~ /$re/)) {
       $cap[0] = {
@@ -83,7 +93,7 @@ sub match_path_strip {
       return @cap;
     }
     return;
-  }
+  })
 }
 
 sub match_extension {
@@ -92,25 +102,25 @@ sub match_extension {
   my $re = $wild
              ? qr/\.(\w+)$/
              : qr/\.(\Q${extension}\E)$/;
-  sub {
+  _matcher(sub {
     if ($_[0]->{PATH_INFO} =~ $re) {
       ($wild ? ({}, $1) : {});
     } else {
       ();
     }
-  };
+   });
 }
 
 sub match_query {
-  _param_matcher(query => $_[0]);
+  _matcher(_param_matcher(query => $_[0]));
 }
 
 sub match_body {
-  _param_matcher(body => $_[0]);
+  _matcher(_param_matcher(body => $_[0]));
 }
 
 sub match_uploads {
-  _param_matcher(uploads => $_[0]);
+  _matcher(_param_matcher(uploads => $_[0]));
 }
 
 sub _param_matcher {
